library(shiny)
library(currentSurvival)

# load the data
#data(cml)
rm(list=ls())

# Define server logic required to plot current survival measures
shinyServer(function(input, output) {

  # Return the formula text for printing as a caption of a plot - CCI
  output$caption_figure_cci <- renderText({
    inFile <- input$file1
    if (is.null(inFile)) {
      return(NULL)
    } else {
      "Figure"
    }
  })

  # Generate a plot of the requested measure - CCI
  output$cursurvPlot_cci <- renderPlot({
    inFile <- input$file1
    if (is.null(inFile))
      return(NULL)
    data<-read.table(inFile$datapath, header=input$header, sep=input$sep, dec=input$dec) 
    if(input$confint==FALSE){
      res <- cci(data)
    } else {
      res <- cci(data,conf.int=TRUE,no.iter=input$ci_noiter)
    }
  })

  # Return the formula text for printing as a caption of a table - CCI
  output$caption_table_cci <- renderText({
    inFile <- input$file1
    if (is.null(inFile)) {
      return(NULL)
    } else {
      "Table"
    }
  })

  # table with estimates - CCI
  output$table_cci<- renderTable({
    inFile <- input$file1
    if (is.null(inFile))
      return(NULL)  
    data<-read.table(inFile$datapath, header=input$header, sep=input$sep, dec=input$dec)  
    if(input$confint==FALSE){
      res <- cci(data,fig=FALSE)
    } else {
      res <- cci(data,conf.int=TRUE,no.iter=input$ci_noiter,fig=FALSE)
    }
    res$pest
  })

  # Return the formula text for printing as a caption of a plot - CLFS
  output$caption_figure_clfs <- renderText({
    inFile <- input$file1
    if (is.null(inFile)) {
      return(NULL)
    } else {
      "Figure"
    }
  })

  # Generate a plot of the requested measure - CLFS
  output$cursurvPlot_clfs <- renderPlot({
    inFile <- input$file1
    if (is.null(inFile))
      return(NULL)
    data<-read.table(inFile$datapath, header=input$header, sep=input$sep, dec=input$dec) 
    if(input$confint==FALSE){
      res <- clfs(data)
    } else {
      res <- clfs(data,conf.int=TRUE,no.iter=input$ci_noiter)
    }
  })

  # Return the formula text for printing as a caption of a table - CLFS
  output$caption_table_clfs <- renderText({
    inFile <- input$file1
    if (is.null(inFile)) {
      return(NULL)
    } else {
      "Table"
    }
  })

  # table with estimates - CLFS
  output$table_clfs<- renderTable({
    inFile <- input$file1
    if (is.null(inFile))
      return(NULL)  
    data<-read.table(inFile$datapath, header=input$header, sep=input$sep, dec=input$dec)  
    if(input$confint==FALSE){
      res <- clfs(data,fig=FALSE)
    } else {
      res <- clfs(data,conf.int=TRUE,no.iter=input$ci_noiter,fig=FALSE)
    }
    res$pest
  })

})

