library(shiny)
library(currentSurvival)

# load the data
data(cml)

# Define server logic required to plot current survival measures
shinyServer(function(input, output) {

  # Compute the formula text in a reactive expression
  formulaText <- reactive({
    paste("Figure - ", input$measure)
  })

  # Return the formula text for printing as a caption of a plot
  output$caption <- renderText({
    formulaText()
  })

  # Generate a plot of the requested measure
  output$cursurvPlot <- renderPlot({
    if(input$measure=="cci"){
       if(input$strat==0){
         if(input$confint==FALSE){
           res <- cci(cml[,c(1:7)])
         } else {
           res <- cci(cml[,c(1:7)],conf.int=TRUE,no.iter=input$ci_noiter)
         }
       } else {         
         if(input$confint==FALSE){
           res <- cci(cml[,c(1:7,as.numeric(input$stratfac))],com.est=FALSE,strat=TRUE)
         } else {
           res <- cci(cml[,c(1:7,as.numeric(input$stratfac))],com.est=FALSE,strat=TRUE,conf.int=TRUE,no.iter=input$ci_noiter)
         }       
       }
    } else {
       if(input$strat==0){
         if(input$confint==FALSE){
           res <- clfs(cml[,c(1:7)])
         } else {
           res <- clfs(cml[,c(1:7)],conf.int=TRUE,no.iter=input$ci_noiter)
         }
       } else {
         if(input$confint==FALSE){
           res <- clfs(cml[,c(1:7,as.numeric(input$stratfac))],com.est=FALSE,strat=TRUE)
         } else {
           res <- clfs(cml[,c(1:7,as.numeric(input$stratfac))],com.est=FALSE,strat=TRUE,conf.int=TRUE,no.iter=input$ci_noiter)
         }       
       }
    }
  })

  # Compute the formula text in a reactive expression
  formulaText2 <- reactive({
    paste("Table - ", input$measure)
  })

  # Return the formula text for printing as a caption of a plot
  output$caption2 <- renderText({
    formulaText2()
  })

  # table with estimates (it's necessary to calculate "res" again because it can't be used from the upper calculation
  output$view <- renderTable({
    if(input$measure=="cci"){
       if(input$strat==0){
         if(input$confint==FALSE){
           res <- cci(cml[,c(1:7)],fig=FALSE)
         } else {
           res <- cci(cml[,c(1:7)],conf.int=TRUE,no.iter=input$ci_noiter,fig=FALSE)
         }
       } else {         
         if(input$confint==FALSE){
           res <- cci(cml[,c(1:7,as.numeric(input$stratfac))],com.est=FALSE,strat=TRUE,fig=FALSE)
         } else {
           res <- cci(cml[,c(1:7,as.numeric(input$stratfac))],com.est=FALSE,strat=TRUE,conf.int=TRUE,no.iter=input$ci_noiter,fig=FALSE)
         }       
       }
    } else {
       if(input$strat==0){
         if(input$confint==FALSE){
           res <- clfs(cml[,c(1:7)],fig=FALSE)
         } else {
           res <- clfs(cml[,c(1:7)],conf.int=TRUE,no.iter=input$ci_noiter,fig=FALSE)
         }
       } else {
         if(input$confint==FALSE){
           res <- clfs(cml[,c(1:7,as.numeric(input$stratfac))],com.est=FALSE,strat=TRUE,fig=FALSE)
         } else {
           res <- clfs(cml[,c(1:7,as.numeric(input$stratfac))],com.est=FALSE,strat=TRUE,conf.int=TRUE,no.iter=input$ci_noiter,fig=FALSE)
         }       
       }
    }
  res$pest
  })

})